#!/bin/sh
set -e
set -x

# reference sequences
bin/prepare-refseqs.pl --gff ../scf1117875582023.gff

# lots of features
bin/biodb-to-json.pl --conf ../pythium-1.conf

# RepeatMasker
bin/flatfile-to-json.pl --trackLabel repeatmasker --type match:repeatmasker --getType --getSubfeatures --key RepeatMasker --arrowheadClass arrowhead --className generic_parent --subfeatureClasses '{"match_part" : "feature"}' --gff ../repeats.gff

# RepeatRunner
bin/flatfile-to-json.pl --trackLabel repeatrunner --type protein_match:repeatrunner --getType --getSubfeatures --key RepeatRunner --arrowheadClass arrowhead --className generic_parent --subfeatureClasses '{"match_part" : "feature"}' --gff ../repeats.gff

# BAM short read alignments
echo '{
       "label" : "bam_alignments",
       "key" : "BAM alignments",
       "storeClass" : "JBrowse/Store/SeqFeature/BAM",
       "urlTemplate" : "../../simulated-sorted.bam",
       "type" : "Alignments2"
     }' | bin/add-track-json.pl data/trackList.json

# BAM coverage bigwig
echo ' {
        "label" : "bam_coverage",
        "key" : "BAM coverage",
        "storeClass" : "BigWig",
        "urlTemplate" : "../../simulated-sorted.bam.coverage.bw",
        "type" : "Wiggle",
        "variance_band" : true
      } ' | bin/add-track-json.pl data/trackList.json

# VCF variants
echo ' {
       "label" : "bam_variation",
       "key" : "VCF simulated variation",
       "storeClass" : "JBrowse/Store/SeqFeature/VCFTabix",
       "urlTemplate" : "../../simulated-sorted.vcf.gz",
       "type" : "HTMLVariants"
     } ' | bin/add-track-json.pl data/trackList.json

# copy track metadata into place
cp ../trackMetadata.csv data/

# index feature names
bin/generate-names.pl
